/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { WebElementCondition, Locator } from "selenium-webdriver";
import { IWebDriver2 } from './webdriver2';
export interface IPageObject {
    clickOn(locator: Locator): Promise<void>;
    elementExists(locator: Locator): Promise<boolean>;
    clickAndWaitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), locator: Locator, timeout?: number): Promise<T>;
    waitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), timeout?: number): Promise<T>;
    isReadyConditions(): WebElementCondition[];
    waitUntilReady(timeout?: number): Promise<void>;
}
export declare function waitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), driver: IWebDriver2, timeout?: number): Promise<T>;
export declare function clickAndWaitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), driver: IWebDriver2, locator: Locator, timeout?: number): Promise<T>;
export declare class PageObject implements IPageObject {
    clickOn(locator: Locator): Promise<void>;
    private static defaultTimeout;
    private timeout?;
    private getTimeout;
    static setDefaultTimeout(ms: number): void;
    protected webDriver2: IWebDriver2;
    constructor(driver: IWebDriver2, timeout?: number);
    elementExists(locator: Locator): Promise<boolean>;
    isReadyConditions(): WebElementCondition[];
    waitUntilReady(timeout?: number): Promise<void>;
    clickAndWaitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), locator: Locator, timeout?: number): Promise<T>;
    waitForPage<T extends IPageObject>(type: (new (...args: any[]) => T), timeout?: number): Promise<T>;
    private static waitForConditions;
}
