"use strict";
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
;
function getInstance(type, ...args) {
    return new type(...args);
}
;
function waitForPage(type, driver, timeout) {
    const page = getInstance(type, driver);
    return new Promise((resolve) => {
        page.waitUntilReady(timeout).then(() => resolve(page));
    });
}
exports.waitForPage = waitForPage;
function clickAndWaitForPage(type, driver, locator, timeout) {
    return new Promise((resolve) => {
        driver.getBy(locator, timeout)
            .then(el => { return el.click(); })
            .then(() => { return waitForPage(type, driver, timeout); })
            .then(page => resolve(page));
    });
}
exports.clickAndWaitForPage = clickAndWaitForPage;
class PageObject {
    constructor(driver, timeout) {
        this.timeout = timeout;
        this.webDriver2 = driver;
    }
    clickOn(locator) {
        return this.webDriver2.getBy(locator).click();
    }
    getTimeout(timeout) {
        if (timeout)
            return timeout;
        if (this.timeout)
            return this.timeout;
        return PageObject.defaultTimeout;
    }
    static setDefaultTimeout(ms) {
        this.defaultTimeout = ms;
    }
    elementExists(locator) {
        return new Promise(resolve => this.webDriver2.seleniumDriver().findElement(locator)
            .then(() => resolve(true))
            .catch(() => resolve(false)));
    }
    isReadyConditions() {
        throw new Error("Not implemented");
    }
    waitUntilReady(timeout) {
        const webDriver = this.webDriver2.seleniumDriver();
        if (webDriver) {
            return PageObject.waitForConditions(webDriver, this.isReadyConditions(), this.getTimeout(timeout));
        }
        else {
            return Promise.reject("no driver found");
        }
    }
    clickAndWaitForPage(type, locator, timeout) {
        return clickAndWaitForPage(type, this.webDriver2, locator, this.getTimeout(timeout));
    }
    waitForPage(type, timeout) {
        return waitForPage(type, this.webDriver2, this.getTimeout(timeout));
    }
    static waitForConditions(driver, conditions, timeout) {
        return __awaiter(this, void 0, void 0, function* () {
            for (var i = 0; i < conditions.length; i++) {
                if (conditions[i]) {
                    yield driver.wait(conditions[i], timeout);
                }
            }
        });
    }
}
PageObject.defaultTimeout = 20000; //ms
exports.PageObject = PageObject;
//# sourceMappingURL=pageobject.js.map